@@ -22,6 +22,7 @@
 #'   
 #' @param A A 3D array (p x k x n) containing GPA-aligned coordinates for all specimens, or a matrix (n x variables)
 #' @param partition.gp A list of which landmarks (or variables) belong in which partition (e.g. A,A,A,B,B,B,C,C,C)
+#' @param ShowPlot A logical value indicating whether or not the plot should be returned
 #' @param iter Number of iterations for significance testing
 #' @export
 #' @keywords analysis
@@ -42,7 +43,7 @@
 #'
 #' compare.modular.partitions(Y.gpa$coords,land.gps,iter=99)
 #' #Result implies that the skull and mandible are not independent modules
-compare.modular.partitions<-function(A,partition.gp,iter=999){
+compare.modular.partitions<-function(A,partition.gp,ShowPlot=TRUE,iter=999){
   if(any(is.na(A))==T){
     stop("Data matrix contains missing values. Estimate these first (see 'estimate.missing').")}
   partition.gp<-as.factor(partition.gp)
@@ -92,7 +93,8 @@ compare.modular.partitions<-function(A,partition.gp,iter=999){
   }
   RV.val[iter+1]=RV.obs
   P.val<-P.val/(iter+1)
+  if(ShowPlot==TRUE){ 
   hist(RV.val,30,freq=TRUE,col="gray",xlab="RV Coefficient")
-  arrows(RV.obs,50,RV.obs,5,length=0.1,lwd=2)
+  arrows(RV.obs,50,RV.obs,5,length=0.1,lwd=2) }
   return(list(RV=RV.obs,pvalue=P.val,RV.min=RV.min,RV.min.partitions=partition.min))
 }
\ No newline at end of file
