@@ -42,9 +42,10 @@ morphol.disparity <- function(A, groups, iter = 999){
   if(m > 1){
     d.obs <- by(y, groups, procvar)
     diff.d.obs <- as.matrix(dist(d.obs))
-    PDisp <- array(1, dim = c(m, m))
-    for (i in 1:iter){
-      y.r <- y[sample(nrow(y)),]
+    PDisp <- array(, dim = c(m, m))
+    ind <- perm.index(nrow(y),iter)
+    for (i in (1:iter+1)){
+      y.r <- y[ind[[i]],]
       d.rand <- by(y.r, groups, procvar)
       diff.d.rand <- as.matrix(dist(d.rand))
       PDisp <- ifelse(diff.d.rand >= diff.d.obs, PDisp + 1, PDisp)
