@@ -56,27 +56,35 @@
 #' ### Example of D-PGLS for high-dimensional data 
 #' data(plethspecies)
 #' Y.gpa<-gpagen(plethspecies$land)    #GPA-alignment
-#' procD.pgls(Y.gpa$coords ~ Y.gpa$Csize,plethspecies$phy,iter=49)
+#' procD.pgls(Y.gpa$coords ~ Y.gpa$Csize,plethspecies$phy,iter=999)
 #'
 #' ### Example of D-PGLS for high-dimensional data, using RRPP
-#' procD.pgls(Y.gpa$coords ~ Y.gpa$Csize,plethspecies$phy,iter=49,RRPP=TRUE)
+#' procD.pgls(Y.gpa$coords ~ Y.gpa$Csize,plethspecies$phy,iter=999,RRPP=TRUE)
 procD.pgls<-function(f1, phy, iter=999, int.first = FALSE, RRPP=FALSE, verbose=FALSE, ...){
-  dat <- as.data.frame(model.frame(f1[-2]))
+  dat <- procD.data.frame(f1)
   if(any(class(f1)=="lm")) pf = procD.fit(f1,weights=f1$weights, contrasts=f1$contrasts, offset=f1$offset) else 
     pf= procD.fit(f1, data=dat,...)
   if(int.first == TRUE) ko = TRUE else ko = FALSE
   Terms <- pf$Terms
   k <- length(pf$Terms)
-  Y <- as.matrix(pf$Y.prime)
+  Y <- pf$Y.prime
+  if(is.null(dim(Y))) {
+    y.names <- names(Y)
+    Y <- matrix(Y) 
+    rownames(Y) <- y.names
+  } else {
+    y.names <- dimnames(Y)[[1]]
+    Y <- as.matrix(Y)
+  }
   if (is.null(dimnames(Y)[[1]])) {
     stop("No species names with Y-data")
-  }
+  } 
   N<-length(phy$tip.label)
   if(length(match(rownames(Y), phy$tip.label))!=N) 
     stop("Data matrix missing some taxa present on the tree.")
   if(length(match(phy$tip.label,rownames(Y)))!=N) 
     stop("Tree missing some taxa in the data matrix.")
-  C<-vcv.phylo(phy); C<-C[rownames(Y),rownames(Y)]  
+  C<-vcv.phylo(phy)
   eigC <- eigen(C)
   lambda <- zapsmall(eigC$values)
   if(any(lambda == 0)){
@@ -85,6 +93,8 @@ procD.pgls<-function(f1, phy, iter=999, int.first = FALSE, RRPP=FALSE, verbose=F
   }
   eigC.vect = eigC$vectors[,1:(length(lambda))]
   Pcor <- solve(eigC.vect%*% diag(sqrt(lambda)) %*% t(eigC.vect)) 
+  dimnames(Pcor) <-dimnames(C)
+  Pcor<-Pcor[y.names,y.names]  
   PY <- Pcor%*%Y   
   Xs <- pf$Xs
   anova.parts.obs <- anova.pgls.parts(pf, X=NULL, Pcor, Yalt = "observed", keep.order=ko)
