@@ -59,8 +59,10 @@ readland.nts<-function(file){
   tmp<-unlist(strsplit(ntsfile[-1],"\\s+"))
   speclab<-NULL; 
   if(r.lab==TRUE){
-    speclab<-ntsfile[2:(1+n)]
-    tmp <- tmp[c((length(tmp)-(p*k)+1):length(tmp))]
+#     speclab<-ntsfile[2:(1+n)]
+#     tmp <- tmp[c((length(tmp)-(p*k)+1):length(tmp))]
+      speclab<-tmp[1:n]
+      tmp<-tmp[-(1:length(speclab))]  
   }
   if(c.lab==TRUE){ tmp<-tmp[-(1:(p*k))] }
   if(missdata==TRUE){tmp[grep(missval,as.integer(tmp))] <- NA}
